@@ -6,10 +6,10 @@
 SAMPLE_BEGIN(AnchorImage)
 
 // Create an anchor that links to a URL through an image.
-Wt::WLink link = Wt::WLink("http://www.emweb.be/");
+Wt::WLink link = Wt::WLink("https://www.emweb.be/");
 link.setTarget(Wt::LinkTarget::NewWindow);
 
-std::unique_ptr<Wt::WAnchor> anchor = Wt::cpp14::make_unique<Wt::WAnchor>(link);
-anchor->addWidget(Wt::cpp14::make_unique<Wt::WImage>(Wt::WLink("pics/emweb_small.jpg")));
+std::unique_ptr<Wt::WAnchor> anchor = std::make_unique<Wt::WAnchor>(link);
+anchor->addNew<Wt::WImage>(Wt::WLink("https://www.emweb.be/css/emweb_small.png"));
 
 SAMPLE_END(return std::move(anchor))
